--[[

This is an example file containing info on how to use the crime spree hook for your custom heist(s).

Things marked as ?TEXT? are supposed to be replaced in their entirety with whatever TEXT represents.
	For example: "?YOUR_NAME?" -> "John"
	Another example: "?YOUR_AGE?" -> "20"

Note that the ?? (question marks) should be removed and are only used to clarify what to adjust.


Once you've read and understood a piece of comment, you can remove it. This will make your file A LOT cleaner and easier to read.

]]--

--[[

If you've made a custom heist with the new format, you can add the following into your "main.xml" file to hook it:

	<Hooks>
		<hook file="?DIRECTORY_OF_HOOK?/?FILE_NAME_HERE?.lua" source_file="lib/tweak_data/crimespreetweakdata"/>
	</Hooks>

This should go somewhere near the top, e.g. slightly below <Localization>.

If you're still using the old format, you can simply add the hook to the "mod.txt" file (copy the source_file from the code snippet above) and paste the file into your mod directory.

]]--

--[[

This line copies the previous "initCustomHeists" function and makes sure that it appends the data.
Replace ?UNIQUE_ID_HERE? with a random string of letters and digits.
Preferably 10 characters or longer. If you use the same name as a different mod, the game will crash and by making your unique identifier as unique as possible, you'll make sure this won't ever happen.

]]--

CrimeSpreeTweakData.copyPrevious_?UNIQUE_ID_HERE? = CrimeSpreeTweakData.initCustomHeists;

--[[

This function appends data to the "initCustomHeists" function.

Although you could in theory do anything here, there's two things you should do:
	1) Call the "copyPrevious_XXXX" function you've just assigned to copy all of the data already in the function. This will make sure it appends to the function, instead of straight-up overriding the data.
	2) Call the self:addCustomHeist(...) function to add any amount of heists you'd like to

]]--

function CrimeSpreeTweakData:initCustomHeists(...)
	CrimeSpreeTweakData:copyPrevious_?UNIQUE_ID_HERE?(...)
	
	--[[
		Function: 
			self:addCustomHeist(stage_name <string>, data_table <table>)
		
		Parameter description:
			stage_name: This parameter takes the name of your heist (un-localized) as defined in the "main.xml" table, or in the "Main.lua" file in your old format.
				Parameter type: String (A piece of text)
			data_table: This parameter consists of a table with a bunch of optional parameters. If no parameters are required, leave the table empty: {}
				Parameter type: Table (A list of pieces of data)
				Possible table values:
					stealth: Should the heist appear under the stealth section?
						Default: false
						Parameter type: Boolean (true / false)
					short: Should the heist appear under the short (=true) or long (=false) section? Will be ignored if 'stealth' parameter is set to 'true'
						Default: true
						Parameter type: Boolean (true / false)
					logo: What logo should be shown to the player?
						Default: "csm_crossroads"
						Parameter type: String (A piece of text)
					spreeValue: How much crime spree value should you earn when completing the heist? This will override the default values.
						Default: {5, 7, 10} (One selected based on stealth & short parameters)
						Parameter type: Integer (A number without decimal point, e.g. 1, 39, 291, etc.)
		
		Returns:
			Nil (Nothing)
	]]--
	
	self:addCustomHeist("some_random_heist", {stealth = true, logo = "csm_branchbank", spreeValue = 5})
	self:addCustomHeist("some_other_random_heist", {short = false})
	self:addCustomHeist("another_random_heist", {})
end